Module command

Module command 

Structs

Address
An address contains all of the information needed to find a command in another graph.
AddressResolver
The resolver for an archived Address

Enums

ArchivedPriority
An archived Priority
Priority
Identify how the client will sort the associated Command.
PriorityResolver
The resolver for an archived Priority

Traits

Command
An action message interpreted by its associated policy to affect state.

Type Aliases

CmdId
The ID of a policy command.