#[repr(C)]pub struct Address {
pub id: CmdId,
pub max_cut: MaxCut,
}Expand description
An address contains all of the information needed to find a command in another graph.
The command id identifies the command you’re searching for and the max_cut allows that command to be found efficiently.
Fields
id: CmdIdmax_cut: MaxCutTrait Implementations
Sourceimpl Archive for Address
impl Archive for Address
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Resolver = AddressResolver
type Resolver = AddressResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
impl Copy for Address
Sourceimpl<'de> Deserialize<'de> for Address
impl<'de> Deserialize<'de> for Address
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Address
Sourceimpl Ord for Address
impl Ord for Address
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Address
impl PartialOrd for Address
impl Portable for Address
impl StructuralPartialEq for Address