ClientError

Enum ClientError 

#[non_exhaustive]
pub enum ClientError { NoSuchParent(CmdId), PolicyError(PolicyError), StorageError(StorageError), InitError, NotAuthorized, SessionDeserialize, ParallelFinalize, ConcurrentTransaction, Bug(Bug), }
An error returned by the runtime client.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NoSuchParent(CmdId)



PolicyError(PolicyError)



StorageError(StorageError)



InitError



NotAuthorized



SessionDeserialize



ParallelFinalize

Attempted to braid two parallel finalize commands together.

Policy must be designed such that two parallel finalize commands are never produced.

Currently, this is practically an unrecoverable error. You must wipe all graphs containing the “bad” finalize command and resync from the “good” clients. Otherwise, your network will split into two separate graph states which can never successfully sync.



ConcurrentTransaction



Bug(Bug)