pub enum CommandPlacement {
OnGraphAtOrigin,
OnGraphInBraid,
OffGraph,
}Expand description
Describes the placement when evaluating a command.
Variants
OnGraphAtOrigin
The command is being evaluated in its original location in the graph.
OnGraphInBraid
The command is being evaluated during a braid of the graph.
OffGraph
The command is being evaluated off-graph in an ephemeral session.