pub struct LinearFactPerspective<R> { /* private fields */ }Trait Implementations
Sourceimpl<R: Debug> Debug for LinearFactPerspective<R>
impl<R: Debug> Debug for LinearFactPerspective<R>
Sourceimpl<R: Read> Query for LinearFactPerspective<R>
impl<R: Read> Query for LinearFactPerspective<R>
Sourcetype QueryIterator = QueryIterator
type QueryIterator = QueryIterator
Iterator for
Query::query_prefix.Sourcefn query(
&self,
name: &str,
keys: &[Box<[u8]>],
) -> Result<Option<Box<[u8]>>, StorageError>
fn query( &self, name: &str, keys: &[Box<[u8]>], ) -> Result<Option<Box<[u8]>>, StorageError>
Look up a named fact by an exact match of the compound key.
Sourcefn query_prefix(
&self,
name: &str,
prefix: &[Box<[u8]>],
) -> Result<QueryIterator, StorageError>
fn query_prefix( &self, name: &str, prefix: &[Box<[u8]>], ) -> Result<QueryIterator, StorageError>
Look up all named facts that begin with the prefix of keys, in sorted key order. Read more
Sourceimpl<R: Read> QueryMut for LinearFactPerspective<R>
impl<R: Read> QueryMut for LinearFactPerspective<R>
impl<R: Read> FactPerspective for LinearFactPerspective<R>