pub struct LinearStorage<W> { /* private fields */ }Trait Implementations
Sourceimpl<F: Write> Storage for LinearStorage<F>
impl<F: Write> Storage for LinearStorage<F>
type Perspective = LinearPerspective<<F as Write>::ReadOnly>
type FactPerspective = LinearFactPerspective<<F as Write>::ReadOnly>
type Segment = LinearSegment<<F as Write>::ReadOnly>
type FactIndex = LinearFactIndex<<F as Write>::ReadOnly>
Sourcefn get_linear_perspective(
&self,
parent: Location,
) -> Result<Self::Perspective, StorageError>
fn get_linear_perspective( &self, parent: Location, ) -> Result<Self::Perspective, StorageError>
Returns a linear perspective at the given location.
Sourcefn get_fact_perspective(
&self,
location: Location,
) -> Result<Self::FactPerspective, StorageError>
fn get_fact_perspective( &self, location: Location, ) -> Result<Self::FactPerspective, StorageError>
Returns a fact perspective at the given location, intended for evaluating braids.
The fact perspective will include the facts of the command at the given location.
Sourcefn new_merge_perspective(
&self,
left: Location,
right: Location,
last_common_ancestor: Location,
policy_id: PolicyId,
braid: Self::FactIndex,
) -> Result<Self::Perspective, StorageError>
fn new_merge_perspective( &self, left: Location, right: Location, last_common_ancestor: Location, policy_id: PolicyId, braid: Self::FactIndex, ) -> Result<Self::Perspective, StorageError>
Returns a merge perspective based on the given locations with the braid as prior facts.
Sourcefn get_segment(&self, location: Location) -> Result<Self::Segment, StorageError>
fn get_segment(&self, location: Location) -> Result<Self::Segment, StorageError>
Returns the segment at the given location.
Sourcefn get_head(&self) -> Result<Location, StorageError>
fn get_head(&self) -> Result<Location, StorageError>
Returns the location of head of the graph.
Sourcefn commit(&mut self, segment: Self::Segment) -> Result<(), StorageError>
fn commit(&mut self, segment: Self::Segment) -> Result<(), StorageError>
Sets the given segment as the head of the graph. Returns an error if
the current head is not an ancestor of the provided segment.
Sourcefn write(
&mut self,
perspective: Self::Perspective,
) -> Result<Self::Segment, StorageError>
fn write( &mut self, perspective: Self::Perspective, ) -> Result<Self::Segment, StorageError>
Writes the given perspective to a segment.
Sourcefn write_facts(
&mut self,
facts: Self::FactPerspective,
) -> Result<Self::FactIndex, StorageError>
fn write_facts( &mut self, facts: Self::FactPerspective, ) -> Result<Self::FactIndex, StorageError>
Writes the given fact perspective to a fact index.
Sourcefn get_location(
&self,
address: Address,
) -> Result<Option<Location>, StorageError>
fn get_location( &self, address: Address, ) -> Result<Option<Location>, StorageError>
Returns the location of Command with id if it has been stored by
searching from the head.
Sourcefn get_location_from(
&self,
start: Location,
address: Address,
) -> Result<Option<Location>, StorageError>
fn get_location_from( &self, start: Location, address: Address, ) -> Result<Option<Location>, StorageError>
Returns the location of Command with id by searching from the given location.
Sourcefn get_command_address(
&self,
location: Location,
) -> Result<Address, StorageError>
fn get_command_address( &self, location: Location, ) -> Result<Address, StorageError>
Returns the address of the command at the given location. Read more
Sourcefn get_head_address(&self) -> Result<Address, StorageError>
fn get_head_address(&self) -> Result<Address, StorageError>
Returns the address of the head of the graph.
Sourcefn is_ancestor(
&self,
search_location: Location,
segment: &Self::Segment,
) -> Result<bool, StorageError>
fn is_ancestor( &self, search_location: Location, segment: &Self::Segment, ) -> Result<bool, StorageError>
Determine whether the given location is an ancestor of the given segment.