pub struct MemFactIndex(/* private fields */);Trait Implementations
Sourceimpl Clone for MemFactIndex
impl Clone for MemFactIndex
Sourcefn clone(&self) -> MemFactIndex
fn clone(&self) -> MemFactIndex
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MemFactIndex
impl Debug for MemFactIndex
Sourceimpl Deref for MemFactIndex
impl Deref for MemFactIndex
Sourceimpl Query for MemFactIndex
impl Query for MemFactIndex
Sourcetype QueryIterator = Box<dyn Iterator<Item = Result<Fact, StorageError>>>
type QueryIterator = Box<dyn Iterator<Item = Result<Fact, StorageError>>>
Iterator for
Query::query_prefix.Sourcefn query(
&self,
name: &str,
keys: &[Box<[u8]>],
) -> Result<Option<Box<[u8]>>, StorageError>
fn query( &self, name: &str, keys: &[Box<[u8]>], ) -> Result<Option<Box<[u8]>>, StorageError>
Look up a named fact by an exact match of the compound key.
Sourcefn query_prefix(
&self,
name: &str,
prefix: &[Box<[u8]>],
) -> Result<Self::QueryIterator, StorageError>
fn query_prefix( &self, name: &str, prefix: &[Box<[u8]>], ) -> Result<Self::QueryIterator, StorageError>
Look up all named facts that begin with the prefix of keys, in sorted key order. Read more
impl FactIndex for MemFactIndex