pub struct MemFactPerspective { /* private fields */ }Trait Implementations
Sourceimpl Debug for MemFactPerspective
impl Debug for MemFactPerspective
Sourceimpl Query for MemFactPerspective
impl Query for MemFactPerspective
Sourcetype QueryIterator = Box<dyn Iterator<Item = Result<Fact, StorageError>>>
type QueryIterator = Box<dyn Iterator<Item = Result<Fact, StorageError>>>
Iterator for
Query::query_prefix.Sourcefn query(
&self,
name: &str,
keys: &[Box<[u8]>],
) -> Result<Option<Box<[u8]>>, StorageError>
fn query( &self, name: &str, keys: &[Box<[u8]>], ) -> Result<Option<Box<[u8]>>, StorageError>
Look up a named fact by an exact match of the compound key.
Sourcefn query_prefix(
&self,
name: &str,
prefix: &[Box<[u8]>],
) -> Result<Self::QueryIterator, StorageError>
fn query_prefix( &self, name: &str, prefix: &[Box<[u8]>], ) -> Result<Self::QueryIterator, StorageError>
Look up all named facts that begin with the prefix of keys, in sorted key order. Read more
Sourceimpl QueryMut for MemFactPerspective
impl QueryMut for MemFactPerspective
impl FactPerspective for MemFactPerspective