pub struct MemPerspective { /* private fields */ }Trait Implementations
Sourceimpl Debug for MemPerspective
impl Debug for MemPerspective
Sourceimpl Perspective for MemPerspective
impl Perspective for MemPerspective
Sourcefn add_command(&mut self, command: &impl Command) -> Result<usize, StorageError>
fn add_command(&mut self, command: &impl Command) -> Result<usize, StorageError>
Adds the given command to the head of the perspective. The command’s
parent must be the head of the perspective.
Sourceimpl Query for MemPerspective
impl Query for MemPerspective
Sourcetype QueryIterator = <MemFactPerspective as Query>::QueryIterator
type QueryIterator = <MemFactPerspective as Query>::QueryIterator
Iterator for
Query::query_prefix.Sourcefn query(
&self,
name: &str,
keys: &[Box<[u8]>],
) -> Result<Option<Box<[u8]>>, StorageError>
fn query( &self, name: &str, keys: &[Box<[u8]>], ) -> Result<Option<Box<[u8]>>, StorageError>
Look up a named fact by an exact match of the compound key.
Sourcefn query_prefix(
&self,
name: &str,
prefix: &[Box<[u8]>],
) -> Result<Self::QueryIterator, StorageError>
fn query_prefix( &self, name: &str, prefix: &[Box<[u8]>], ) -> Result<Self::QueryIterator, StorageError>
Look up all named facts that begin with the prefix of keys, in sorted key order. Read more
Sourceimpl QueryMut for MemPerspective
impl QueryMut for MemPerspective
Sourceimpl Revertable for MemPerspective
impl Revertable for MemPerspective
Sourcefn checkpoint(&self) -> Checkpoint
fn checkpoint(&self) -> Checkpoint
Create a checkpoint which can be used to revert the perspective.
impl FactPerspective for MemPerspective