pub struct MemSegment(/* private fields */);Trait Implementations
Sourceimpl Clone for MemSegment
impl Clone for MemSegment
Sourcefn clone(&self) -> MemSegment
fn clone(&self) -> MemSegment
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MemSegment
impl Debug for MemSegment
Sourceimpl Deref for MemSegment
impl Deref for MemSegment
Sourceimpl From<MemSegmentInner> for MemSegment
impl From<MemSegmentInner> for MemSegment
Sourcefn from(segment: MemSegmentInner) -> Self
fn from(segment: MemSegmentInner) -> Self
Converts to this type from the input type.
Sourceimpl Segment for MemSegment
impl Segment for MemSegment
type FactIndex = MemFactIndex
type Command<'a> = &'a MemCommand
Sourcefn index(&self) -> SegmentIndex
fn index(&self) -> SegmentIndex
Returns the segment’s index.
Sourcefn first_location(&self) -> Location
fn first_location(&self) -> Location
Returns the location of the first command.
Sourcefn get_command(&self, location: Location) -> Option<&MemCommand>
fn get_command(&self, location: Location) -> Option<&MemCommand>
Returns the command at the given location.
Sourcefn longest_max_cut(&self) -> Result<MaxCut, StorageError>
fn longest_max_cut(&self) -> Result<MaxCut, StorageError>
The longest max cut for this segment. Read more
Sourcefn shortest_max_cut(&self) -> MaxCut
fn shortest_max_cut(&self) -> MaxCut
The shortest max cut for this segment. Read more
Sourcefn skip_list(&self) -> &[Location]
fn skip_list(&self) -> &[Location]
The skip list is a series of locations that can be safely jumped to
when searching for a location. As long as the max cut of the location
you’re jumping to is greater than or equal to the location you’re
searching for you can jump to it and be guaranteed not to miss
the location you’re searching for. Read more
Sourcefn facts(&self) -> Result<Self::FactIndex, StorageError>
fn facts(&self) -> Result<Self::FactIndex, StorageError>
Get the fact index associated with this segment.
Sourcefn get_from(&self, location: Location) -> Vec<Self::Command<'_>>
fn get_from(&self, location: Location) -> Vec<Self::Command<'_>>
Returns an iterator of commands starting at the given location.
Sourcefn get_by_address(&self, address: Address) -> Option<Location>
fn get_by_address(&self, address: Address) -> Option<Location>
Returns the location of the command with the given address from within this segment.
Sourcefn head_location(&self) -> Result<Location, StorageError>
fn head_location(&self) -> Result<Location, StorageError>
Returns the location of the head of the segment.
Sourcefn head_address(&self) -> Result<Address, StorageError>
fn head_address(&self) -> Result<Address, StorageError>
Returns the address of the head of the segment.