pub struct Location {
pub segment: usize,
pub command: usize,
}Fields
segment: usizecommand: usizeImplementations
Sourceimpl Location
impl Location
pub fn new(segment: usize, command: usize) -> Location
Sourcepub fn previous(self) -> Option<Self>
pub fn previous(self) -> Option<Self>
If this is not the first command in a segment, return a location pointing to the previous command.
Sourcepub fn same_segment(self, other: Location) -> bool
pub fn same_segment(self, other: Location) -> bool
Returns true if other location is in the same segment.