#[repr(transparent)]pub struct MaxCut(pub usize);Tuple Fields
0: usizeImplementations
Sourceimpl MaxCut
impl MaxCut
Sourcepub fn checked_add(self, other: usize) -> Option<Self>
pub fn checked_add(self, other: usize) -> Option<Self>
Adds an amount to the max cut, returning None on overflow.
Sourcepub fn decremented(self) -> Option<Self>
pub fn decremented(self) -> Option<Self>
Gets a max cut one lower than this, returning None on overflow.
Sourcepub fn distance_from(self, other: Self) -> Option<usize>
pub fn distance_from(self, other: Self) -> Option<usize>
Gets the distance between two max cuts, returning None on overflow.