QueryMut

Trait QueryMut 

pub trait QueryMut: Query {
    // Required methods
    fn insert(&mut self, name: String, keys: Keys, value: Box<[u8]>);
    fn delete(&mut self, name: String, keys: Keys);
}
Can mutate facts by inserting and deleting them.

See Query for details on the nature of facts.

Required Methods

fn insert(&mut self, name: String, keys: Keys, value: Box<[u8]>)

Insert a fact labeled by a name, with a given compound key and a value.

This fact can later be looked up by Query methods, using the name and keys.

fn delete(&mut self, name: String, keys: Keys)

Delete any fact associated to the compound key, under the given name.

Implementors