Struct ClientState

pub struct ClientState<E, SP> { /* private fields */ }
Keeps track of client graph state.

Implementations

Source

impl<E, SP> ClientState<E, SP>

pub const fn new(engine: E, provider: SP) -> ClientState<E, SP>

Creates a ClientState.

pub fn provider(&mut self) -> &mut SP

Provide access to the StorageProvider.

Source

impl<E, SP> ClientState<E, SP>
where E: Engine, SP: StorageProvider,

pub fn new_graph( &mut self, policy_data: &[u8], action: <E::Policy as Policy>::Action<'_>, sink: &mut impl Sink<E::Effect>, ) -> Result<GraphId, ClientError>

Create a new graph (AKA Team). This graph will start with the initial policy provided which must be compatible with the engine E. The payload is the initial init message that will bootstrap the graph facts. Effects produced when processing the payload are emitted to the sink.

pub fn commit( &mut self, trx: &mut Transaction<SP, E>, sink: &mut impl Sink<E::Effect>, ) -> Result<(), ClientError>

Commit the Transaction to storage, after merging all temporary heads.

pub fn add_commands( &mut self, trx: &mut Transaction<SP, E>, sink: &mut impl Sink<E::Effect>, commands: &[impl Command], request_heads: &mut PeerCache, ) -> Result<usize, ClientError>

Add commands to the transaction, writing the results to sink. Returns the number of commands that were added.

pub fn action( &mut self, storage_id: GraphId, sink: &mut impl Sink<E::Effect>, action: <E::Policy as Policy>::Action<'_>, ) -> Result<(), ClientError>

Performs an action, writing the results to sink.

Source

impl<E, SP> ClientState<E, SP>
where SP: StorageProvider,

pub fn transaction(&mut self, storage_id: GraphId) -> Transaction<SP, E>

Create a new Transaction, used to receive Commands when syncing.

pub fn session( &mut self, storage_id: GraphId, ) -> Result<Session<SP, E>, ClientError>

Create an ephemeral Session associated with this client.