pub struct Session<SP: StorageProvider, E> { /* private fields */ }Expand description
Ephemeral session used to handle/generate off-graph commands.
Implementations
Sourceimpl<SP: StorageProvider, E: Engine> Session<SP, E>
impl<SP: StorageProvider, E: Engine> Session<SP, E>
Sourcepub fn action<ES, MS>(
&mut self,
client: &ClientState<E, SP>,
effect_sink: &mut ES,
message_sink: &mut MS,
action: <E::Policy as Policy>::Action<'_>,
) -> Result<(), ClientError>
pub fn action<ES, MS>( &mut self, client: &ClientState<E, SP>, effect_sink: &mut ES, message_sink: &mut MS, action: <E::Policy as Policy>::Action<'_>, ) -> Result<(), ClientError>
Evaluate an action on the ephemeral session and generate serialized
commands, so another client can Session::receive them.
Sourcepub fn receive(
&mut self,
client: &ClientState<E, SP>,
sink: &mut impl Sink<E::Effect>,
command_bytes: &[u8],
) -> Result<(), ClientError>
pub fn receive( &mut self, client: &ClientState<E, SP>, sink: &mut impl Sink<E::Effect>, command_bytes: &[u8], ) -> Result<(), ClientError>
Handle a command from another client generated by Session::action.
You do NOT need to reprocess the commands from actions generated in the same session.