pub struct Transaction<SP: StorageProvider, E> { /* private fields */ }Expand description
Transaction used to receive many commands at once.
The transaction allows us to have many temporary heads at once, so we don’t need as many merges when adding commands. When the transaction is committed, we will merge all temporary heads and the storage head, and then commit the result as the new storage head.
Implementations
Sourceimpl<SP: StorageProvider, E: Engine> Transaction<SP, E>
impl<SP: StorageProvider, E: Engine> Transaction<SP, E>
Sourcepub fn storage_id(&self) -> GraphId
pub fn storage_id(&self) -> GraphId
Returns the transaction’s storage id.