SyncRequestMessage

Enum SyncRequestMessage 

pub enum SyncRequestMessage {
    SyncRequest {
        session_id: u128,
        graph_id: GraphId,
        max_bytes: u64,
        commands: Vec<Address, COMMAND_SAMPLE_MAX>,
    },
    RequestMissing {
        session_id: u128,
        indexes: Vec<u64, REQUEST_MISSING_MAX>,
    },
    SyncResume {
        session_id: u128,
        response_index: u64,
        max_bytes: u64,
    },
    EndSession {
        session_id: u128,
    },
}
Messages sent from the requester to the responder.

Variants



SyncRequest

Initiate a new Sync

Fields

session_id: u128

A new random value produced by a cryptographically secure RNG.

graph_id: GraphId

Specifies the graph to be synced.

max_bytes: u64

Specifies the maximum number of bytes worth of commands that the requester wishes to receive.

commands: Vec<Address, COMMAND_SAMPLE_MAX>

Sample of the commands held by the requester. The responder should respond with any commands that the requester may not have based on the provided sample. When sending commands ancestors must be sent before descendents.



RequestMissing

Sent by the requester if it deduces a SyncResponse message has been dropped.

Fields

session_id: u128

A random-value produced by a cryptographically secure RNG corresponding to the session_id in the initial SyncRequest.

indexes: Vec<u64, REQUEST_MISSING_MAX>

SyncResponse indexes that the requester has not received.



SyncResume

Message to request the responder resumes sending SyncResponses following the specified message. This may be sent after a requester timeout or after a SyncEnd has been sent.

Fields

session_id: u128

A random-value produced by a cryptographically secure RNG corresponding to the session_id in the initial SyncRequest.

response_index: u64

Indicates the last response message the requester received.

max_bytes: u64

Updates the maximum number of bytes worth of commands that the requester wishes to receive.



EndSession

Message sent by either requester or responder to indicate the session has been terminated or the session_id is no longer valid.

Fields

session_id: u128

Implementations