SyncType

Enum SyncType 

pub enum SyncType {
    Poll {
        request: SyncRequestMessage,
    },
    Subscribe {
        remain_open: u64,
        max_bytes: u64,
        commands: Vec<Address, COMMAND_SAMPLE_MAX>,
        graph_id: GraphId,
    },
    Unsubscribe {
        graph_id: GraphId,
    },
    Push {
        message: SyncResponseMessage,
        graph_id: GraphId,
    },
    Hello(SyncHelloType),
}
The sync type to dispatch.

Variants



Poll

This will include a sync request and be immediately responded to with a sync response.

Fields

request: SyncRequestMessage

The sync request message.



Subscribe

Subscribes the peer to receive push syncs from this peer. Calling this again will update remain_open and max_bytes for this peer.

Fields

remain_open: u64

The number of seconds the sync request will remain open.

max_bytes: u64

The maximum number of bytes that should be sent.

commands: Vec<Address, COMMAND_SAMPLE_MAX>

A sample of the peer’s graph. This will be used to update the known heads for the peer.

graph_id: GraphId

The graph this request is for.



Unsubscribe

Removes any open subsciptions for the peer. If there is no subscription this will be a noop.

Fields

graph_id: GraphId

Specifies the graph.



Push

This will only be sent to peers who have an open subscription. Contains any new commands that come after the peer’s known heads.

Fields

message: SyncResponseMessage

A message containing commands that the pusher believes the peer does not have.

graph_id: GraphId

The graph this push is for.



Hello(SyncHelloType)

Sync hello message for subscription-based notifications.