pub struct SyncRequester { /* private fields */ }Implementations
Sourceimpl SyncRequester
impl SyncRequester
Sourcepub fn new<R: Csprng>(graph_id: GraphId, rng: R) -> Self
pub fn new<R: Csprng>(graph_id: GraphId, rng: R) -> Self
Create a new SyncRequester with a random session ID.
Sourcepub fn new_session_id(graph_id: GraphId, session_id: u128) -> Self
pub fn new_session_id(graph_id: GraphId, session_id: u128) -> Self
Create a new SyncRequester for an existing session.
Sourcepub fn ready(&self) -> bool
pub fn ready(&self) -> bool
Returns true if Self::poll would produce a message.
Sourcepub fn poll(
&mut self,
target: &mut [u8],
provider: &mut impl StorageProvider,
heads: &mut PeerCache,
) -> Result<(usize, usize), SyncError>
pub fn poll( &mut self, target: &mut [u8], provider: &mut impl StorageProvider, heads: &mut PeerCache, ) -> Result<(usize, usize), SyncError>
Write a sync message in to the target buffer. Returns the number of bytes written and the number of commands sent in the sample.
Sourcepub fn receive<'a>(
&mut self,
data: &'a [u8],
) -> Result<Option<Vec<SyncCommand<'a>, COMMAND_RESPONSE_MAX>>, SyncError>
pub fn receive<'a>( &mut self, data: &'a [u8], ) -> Result<Option<Vec<SyncCommand<'a>, COMMAND_RESPONSE_MAX>>, SyncError>
Receive a sync message. Returns parsed sync commands.
Sourcepub fn get_sync_commands<'a>(
&mut self,
message: SyncResponseMessage,
remaining: &'a [u8],
) -> Result<Option<Vec<SyncCommand<'a>, COMMAND_RESPONSE_MAX>>, SyncError>
pub fn get_sync_commands<'a>( &mut self, message: SyncResponseMessage, remaining: &'a [u8], ) -> Result<Option<Vec<SyncCommand<'a>, COMMAND_RESPONSE_MAX>>, SyncError>
Extract SyncCommands from a SyncResponseMessage and remaining bytes.