Module command

Module command 

Structs

Address
An address contains all of the information needed to find a command in another graph.
CmdId
The ID of a policy command.

Enums

Priority
Identify how the client will sort the associated Command.

Traits

Command
An action message interpreted by its associated policy to affect state.