Structs
- Address
- An address contains all of the information needed to find a command in another graph.
- Command
Id - An ID constructed as a cryptographic hash of a serialized
Command.
Enums
Traits
- Command
- An action message interpreted by its associated policy to affect state.