aranya_runtime

Module command

Structs

  • An address contains all of the information needed to find a command in another graph.
  • An ID constructed as a cryptographic hash of a serialized Command.

Enums

Traits

  • An action message interpreted by its associated policy to affect state.