pub enum Priority {
Merge,
Basic(u32),
Finalize,
Init,
}Expand description
Identify how the client will sort the associated Command.
Variants
Merge
Indicates two branches in the parent graph have been merged at this
command. A command with this priority must have two parents,
Parent::Merge.
Basic(u32)
Indicates a device-specific action; the runtime uses the internal u32 for ordering.
Finalize
Indicates all preceding commands are ancestors of this command.
Init
Indicates state is initialized; the associated command is a common
ancestor to all other commands in the graph. A command with this
priority must have no parents, Parent::None.