pub struct MaxCut(/* private fields */);Implementations
Sourceimpl MaxCut
impl MaxCut
pub const fn new(val: u64) -> Self
pub const fn get(self) -> u64
Sourcepub fn checked_add(self, other: u64) -> Option<Self>
pub fn checked_add(self, other: u64) -> Option<Self>
Adds an amount to the max cut, returning None on overflow.
Sourcepub fn decremented(self) -> Option<Self>
pub fn decremented(self) -> Option<Self>
Gets a max cut one lower than this, returning None on overflow.
Sourcepub fn distance_from(self, other: Self) -> Option<u64>
pub fn distance_from(self, other: Self) -> Option<u64>
Gets the distance between two max cuts, returning None on overflow.