pub enum SyncRequestMessage {
SyncRequest {
session_id: u128,
graph_id: GraphId,
max_bytes: u64,
commands: Vec<Address, COMMAND_SAMPLE_MAX>,
},
RequestMissing {
session_id: u128,
indexes: Vec<u64, REQUEST_MISSING_MAX>,
},
SyncResume {
session_id: u128,
response_index: u64,
max_bytes: u64,
},
EndSession {
session_id: u128,
},
}Expand description
Messages sent from the requester to the responder.
Variants
SyncRequest
Initiate a new Sync
Fields
RequestMissing
Sent by the requester if it deduces a SyncResponse message has been
dropped.
Fields
SyncResume
Message to request the responder resumes sending SyncResponses
following the specified message. This may be sent after a requester
timeout or after a SyncEnd has been sent.
Fields
EndSession
Message sent by either requester or responder to indicate the session
has been terminated or the session_id is no longer valid.
Implementations
Sourceimpl SyncRequestMessage
impl SyncRequestMessage
pub fn session_id(&self) -> u128