pub enum SyncResponseMessage {
SyncResponse {
session_id: u128,
index: u64,
commands: Vec<CommandMeta, COMMAND_RESPONSE_MAX>,
},
SyncEnd {
session_id: u128,
max_index: u64,
remaining: bool,
},
Offer {
session_id: u128,
head: CommandId,
},
EndSession {
session_id: u128,
},
}Expand description
Messages sent from the responder to the requester.
Variants
SyncResponse
Sent in response to a SyncRequest
Fields
index: u64If the responder intends to send a value of command bytes
greater than the responder’s configured maximum, the responder
will send more than one SyncResponse. The first message has an
index of 1, and each following is incremented.
commands: Vec<CommandMeta, COMMAND_RESPONSE_MAX>Commands that the responder believes the requester does not have.
SyncEnd
End a sync session if SyncRequest.max_bytes has been reached or
there are no remaining commands to send.
Fields
Offer
Message sent by a responder after a sync has been completed, but before
the session has ended, if it has new commands in it’s graph. If a
requester wishes to respond to this message, it should do so with a
new SyncRequest. This message may use the existing session_id.
Fields
EndSession
Message sent by either requester or responder to indicate the session
has been terminated or the session_id is no longer valid.