pub enum SyncType {
Poll {
request: SyncRequestMessage,
},
Subscribe {
remain_open: u64,
max_bytes: u64,
commands: Vec<Address, COMMAND_SAMPLE_MAX>,
graph_id: GraphId,
},
Unsubscribe {
graph_id: GraphId,
},
Push {
message: SyncResponseMessage,
graph_id: GraphId,
},
Hello(SyncHelloType),
}Expand description
The sync type to dispatch.
Variants
Poll
This will include a sync request and be immediately responded to with a sync response.
Fields

request: SyncRequestMessageThe sync request message.
Subscribe
Subscribes the peer to receive push syncs from this peer. Calling this again will update remain_open and max_bytes for this peer.
Fields
Unsubscribe
Removes any open subsciptions for the peer. If there is no subscription this will be a noop.
Push
This will only be sent to peers who have an open subscription. Contains any new commands that come after the peer’s known heads.
Fields

message: SyncResponseMessageA message containing commands that the pusher believes the peer does not have.
Hello(SyncHelloType)
Sync hello message for subscription-based notifications.